@@ -158,7 +158,7 @@ def has_equal_part_len(name, unequal_msg, state=None):
     Arguments:
         name (str): name of the part for which to check the length to the corresponding part in the solution.
         unequal_msg (str): Message in case the lengths do not match.
-        state (State): state as passed by the SCT chain. Don't specify this.
+        state (State): state as passed by the SCT chain. Don't specify this explicitly.
 
     :Examples:
 
@@ -406,6 +406,22 @@ def set_env(state = None, **kwargs):
     return state.to_child_state(student_env = stu_new, solution_env = sol_new)
 
 def disable_highlighting(state = None):
+    """Disable highlighting in the remainder of the SCT chain.
+
+    Include this function if you want to avoid that ``pythonwhat`` marks which part of the student submission is incorrect.
+
+    :Examples:
+
+        SCT that will mark the 'number' portion if it is incorrect::
+
+            Ex().check_function('round').check_args(0).has_equal_ast()
+
+        SCT chains that will not mark certain mistakes. The earlier you put the function, the more types of mistakes will no longer be highlighted::
+
+            Ex().disable_highlighting().check_function('round').check_args(0).has_equal_ast()
+            Ex().check_function('round').disable_highlighting().check_args(0).has_equal_ast()
+            Ex().check_function('round').check_args(0).disable_highlighting().has_equal_ast()
+    """
     return state.to_child_state(highlighting_disabled = True)
 
 def check_args(name, missing_msg='FMT:Are you sure it is defined?', state=None):
@@ -457,15 +473,16 @@ def check_args(name, missing_msg='FMT:Are you sure it is defined?', state=None):
             )
 
     """
-    if name in ['*args', '**kwargs']:
+    if name in ['*args', '**kwargs']: # for check_function_def
         return check_part(name, name, state=state, missing_msg = missing_msg)
     else:
-        def build_arg_str(name):
-            return "%s argument"%get_ord(name+1) if isinstance(name, int) else "argument `%s`"%name
         if isinstance(name, list):
-            arg_str = "{} matched through the `{}`".format(build_arg_str(name[1]), name[0])
+            if name[0] == 'args':
+                arg_str = "%s argument passed as a variable length argument"%get_ord(name[1]+1)
+            else:
+                arg_str = "argument `%s`"%name[1]
         else:
-            arg_str = build_arg_str(name)
+            arg_str = "%s argument"%get_ord(name+1) if isinstance(name, int) else "argument `%s`"%name
         return check_part_index('args', name, arg_str, state=state, missing_msg = missing_msg)
 
 
